@@ -4,7 +4,7 @@ from .mixins import CommonMixin, NameMixin, PrintMixin
 
 class UsersService(CommonMixin, NameMixin, PrintMixin):
     def __init__(self, base: BaseService) -> None:
-        super().__init__(base=base)
+        CommonMixin.__init__(self, base)
         self.endpoint = "/api/users"
 
     def disable(self, user_id: int) -> None:
