@@ -13,7 +13,7 @@ class WidgetsService(CommonMixin, PrintMixin):
     """
 
     def __init__(self, base: BaseService) -> None:
-        super().__init__(base=base)
+        CommonMixin.__init__(self, base)
         self.endpoint = "/api/widgets"
 
     def get_all(self) -> NoReturn:
